define(['jquery', 'core/ajax', 'core/str'], ($, Ajax, Str) => {
  const sizePerChunk = 5;
  const retryDelay = 5_000;
  let retryRows = [];
  let loadingCaption = '';
  let defaultFetchStatFailCaption = '';

  const chunk = (rows) => {
    const chunked = []
    for (let i = 0; i < rows.length; i += sizePerChunk) {
      chunked.push(rows.slice(i, i + sizePerChunk))
    }

    return chunked;
  };

  const fetchStat = (row) => {
    const attemptid = row.getAttribute('data-attemptid');
    const cmid = row.getAttribute('data-cmid');
    const wsfunction = 'quizaccess_quilgo_fetch_stat';
    const params = {
      'attemptid': Number(attemptid),
      'cmid': Number(cmid),
    };
    const request = {
      'methodname': wsfunction,
      'args': params
    };

    if (row.getAttribute('data-statstatus') == -1) {
      row.textContent = loadingCaption;
    }

    return Ajax.call([request])[0];
  }

  const fetchStats = async (batches) => {
    for (const batch of batches) {
      
      await Promise.all(
        batch.map((row) => {
          return fetchStat(row)
            .then((res) => {
              row.textContent = res.confidenceLevel;
              row.classList.remove('text-muted');
              row.classList.add(res.textClass);

              if (res.reportStatus !== 1) {
                retryRows.push(row);
              }
            })
            .catch((err) => {
              row.textContent = defaultFetchStatFailCaption;
              retryRows.push(row);
            });
        })
      );
    }

    if (retryRows.length > 0) {
      setTimeout(() => {
        const chunks = chunk(retryRows);
        retryRows = [];
        fetchStats(chunks);
      }, retryDelay);
    }
  };

  return {
    init: async () => {
      const stringsTemplate = await Str.get_strings([
        { key: 'report_table_row_stat_loading', component: 'quizaccess_quilgo' },
        { key: 'report_table_row_stat_not_ready', component: 'quizaccess_quilgo' },
      ]);
      [loadingCaption, defaultFetchStatFailCaption] = stringsTemplate;
      
      const rows = document.querySelectorAll('span#quilgo-report-stat:not([data-statstatus="1"])');
      const chunks = chunk(Array.from(rows));
      fetchStats(chunks);
    }
  }
});
