<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Plugin upgrade steps are defined here.
 * @package     quizaccess_quilgo
 * @copyright   2023 Native Platform Ltd <hello@quilgo.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * Execute quizaccess_quilgo upgrade from the given old version.
 *
 * @param int $oldversion
 * @return bool
 */
function xmldb_quizaccess_quilgo_upgrade($oldversion) {
    global $DB;

    $dbman = $DB->get_manager();

    if ($oldversion < 2024050100) {
        // Define field generate_status to be added to quizaccess_quilgo_reports.
        $table = new xmldb_table('quizaccess_quilgo_reports');
        $field = new xmldb_field('generate_status', XMLDB_TYPE_INTEGER, '1', null, null, null, null, 'error_reason');

        // Conditionally launch add field generate_status.
        if (!$dbman->field_exists($table, $field)) {
            $dbman->add_field($table, $field);
        }

        // Define field stat to be added to quizaccess_quilgo_reports.
        $table = new xmldb_table('quizaccess_quilgo_reports');
        $field = new xmldb_field('stat', XMLDB_TYPE_TEXT, null, null, null, null, null, 'generate_status');

        // Conditionally launch add field stat.
        if (!$dbman->field_exists($table, $field)) {
            $dbman->add_field($table, $field);
        }
        
        // Quilgo savepoint reached.
        upgrade_plugin_savepoint(true, 2024050100, 'quizaccess', 'quilgo');
    }

    return true;
}
